# pydslice_x86_defs.py
#
# Contains various x86/x64 definitions 
#
# Copyright (C) 2016 Josh Burbrink <dev.burbrink@gmail.com>

# x86 Definitions

x86_registers = {
    'eax' : ['eax'],
    'ebx' : ['ebx'],
    'ecx' : ['ecx'],
    'edx' : ['edx'],
    'esp' : ['esp'],
    'ebp' : ['ebp'],
    'esi' : ['esi'],
    'edi' : ['edi'],
    'eip' : ['eip'],
    'eiz' : ['eiz'],
    'ax' : ['eax'],
    'bx' : ['ebx'],
    'cx' : ['ecx'],
    'dx' : ['edx'],
    'si' : ['esi'],
    'di' : ['edi'],
    'bp' : ['bp'],
    'ah' : ['eax'],
    'al' : ['eax'],
    'bh' : ['ebx'],
    'bl' : ['ebx'],
    'ch' : ['ecx'],
    'cl' : ['ecx'],
    'dh' : ['edx'],
    'dl' : ['edx'],
    'spl' : ['esp'],
    'bpl' : ['ebp'],
    'dil' : ['edi'],
    'sil' : ['esi'],
    'cs' : ['cs'],
    'ds' : ['ds'],
    'ss' : ['ss'],
    'es' : ['es'],
    'fs' : ['fs'],
    'gs' : ['gs'],
    'xmm0' : ['xmm0'],
    'xmm1' : ['xmm1'],
    'xmm2' : ['xmm2'],
    'xmm3' : ['xmm3'],
    'xmm4' : ['xmm4'],
    'xmm5' : ['xmm5'],
    'xmm6' : ['xmm6'],
    'xmm7' : ['xmm7'],
    'xmm8' : ['xmm8'],
    'xmm9' : ['xmm9'],
    'xmm10' : ['xmm10'],
    'xmm11' : ['xmm11'],
    'xmm12' : ['xmm12'],
    'xmm13' : ['xmm13'],
    'xmm14' : ['xmm14'],
    'xmm15' : ['xmm15'],
}

x86_syscall_table = {
    0 : [0, "restart_syscall"],
    1 : [1, "_exit"],
    2 : [0, "fork"],
    3 : [3, "read"], 
    4 : [3, "write"],
    5 : [3, "open"],
    6 : [1, "close"],
    7 : [3, "waitpid"],
    8 : [2, "creat"],
    9 : [2, "link"],
    10 : [1, "unlink"],
    11 : [3, "execve"],
    12 : [1, "chdir"],
    13 : [1, "time"], 
    14 : [3, "mknod"],
    15 : [2, "chmod"],
    16 : [3, "lchown"],
    17 : [0, "break"],
    18 : [2, "oldstat"], 
    19 : [3, "lseek"],
    20 : [0, "getpid"],
    21 : [5, "mount"],
    22 : [1, "umount"],
    23 : [1, "setuid"],
    24 : [0, "getuid"],
    25 : [1, "stime"],
    26 : [4, "ptrace"],
    27 : [1, "alarm"],
    28 : [2, "oldfstat"], 
    29 : [0, "pause"],
    30 : [2, "utime"],
    31 : [2, "stty"],
    32 : [2, "gtty"],
    33 : [2, "access"],
    34 : [1, "nice"],
    35 : [0, "ftime"],
    36 : [0, "sync"],
    37 : [2, "kill"],
    38 : [2, "rename"],
    39 : [2, "mkdir"],
    40 : [1, "rmdir"],
    41 : [1, "dup"],
    42 : [1, "pipe"],
    43 : [1, "times"],
    44 : [0, "prof"],
    45 : [1, "brk"],
    46 : [1, "setgid"],
    47 : [0, "getgid"],
    48 : [3, "signal"],
    49 : [0, "geteuid"],
    50 : [0, "getegid"],
    51 : [1, "acct"],
    52 : [2, "umount2"],
    53 : [0, "lock"],
    54 : [3, "ioctl"],
    55 : [3, "fcntl"],
    56 : [0, "mpx"],
    57 : [2, "setpgid"],
    58 : [2, "ulimit"],
    59 : [1, "oldolduname"],
    60 : [1, "umask"],
    61 : [1, "chroot"],
    62 : [2, "ustat"],
    63 : [2, "dup2"],
    64 : [0, "getppid"],
    65 : [0, "getpgrp"],
    66 : [0, "setsid"],
    67 : [3, "sigaction"],
    68 : [0, "sgetmask"],
    69 : [1, "ssetmask"],
    70 : [2, "setreuid"],
    71 : [2, "setregid"],
    72 : [3, "sigsuspend"],
    73 : [1, "sigpending"],
    74 : [2, "sethostname"],
    75 : [2, "setrlimit"],
    76 : [2, "getrlimit"],
    77 : [2, "getrusage"],
    78 : [2, "gettimeofday"],
    79 : [2, "settimeofday"],
    80 : [2, "getgroups"],
    81 : [2, "setgroups"],
    82 : [1, "oldselect"],
    83 : [2, "symlink"],
    84 : [2, "oldlstat"],
    85 : [3, "readlink"],
    86 : [1, "uselib"],
    87 : [2, "swapon"],
    88 : [4, "reboot"],
    89 : [3, "readdir"],
    90 : [6, "old_mmap"],
    91 : [2, "munmap"],
    92 : [2, "truncate"],
    93 : [2, "ftruncate"],
    94 : [2, "fchmod"],
    95 : [3, "fchown"],
    96 : [2, "getpriority"],
    97 : [3, "setpriority"],
    98 : [4, "profil"],
    99 : [2, "statfs"],
    100 : [2, "fstatfs"],
    101 : [3, "ioperm"],
    102 : [2, "socketcall"], # maybe support
    103 : [3, "syslog"],
    104 : [3, "setitimer"],
    105 : [2, "getitimer"],
    106 : [2, "stat"], 
    107 : [2, "lstat"], 
    108 : [2, "fstat"], 
    109 : [1, "olduname"],
    110 : [1, "iopl"],
    111 : [0, "vhangup"],
    112 : [0, "idle"],
    113 : [1, "vm86old"],
    114 : [4, "wait4"],
    115 : [1, "swapoff"],
    116 : [1, "sysinfo"],
    117 : [6, "ipc"],
    118 : [1, "fsync"],
    119 : [0, "sigreturn"],
    120 : [5, "clone"],
    121 : [2, "setdomainname"],
    122 : [1, "uname"],
    123 : [3, "modify_ldt"],
    124 : [1, "adjtimex"],
    125 : [3, "mprotect"],
    126 : [3, "sigprocmask"],
    127 : [2, "create_module"],
    128 : [3, "init_module"],
    129 : [2, "delete_module"],
    130 : [1, "get_kernel_syms"],
    131 : [4, "quotactl"],
    132 : [1, "getpgid"],
    133 : [1, "fchdir"],
    134 : [0, "bdflush"],
    135 : [3, "sysfs"],
    136 : [1, "personality"],
    137 : [5, "afs_syscall"],
    138 : [1, "setfsuid"],
    139 : [1, "setfsgid"],
    140 : [5, "_llseek"],
    141 : [3, "getdents"],
    142 : [5, "select"], 
    143 : [2, "flock"],
    144 : [3, "msync"],
    145 : [3, "readv"],
    146 : [3, "writev"],
    147 : [1, "getsid"],
    148 : [1, "fdatasync"],
    149 : [1, "_sysctl"],
    150 : [2, "mlock"],
    151 : [2, "munlock"],
    152 : [1, "mlockall"],
    153 : [0, "munlockall"],
    154 : [2, "sched_setparam"],
    155 : [2, "sched_getparam"],
    156 : [3, "sched_setscheduler"],
    157 : [1, "sched_getscheduler"],
    158 : [0, "sched_yield"],
    159 : [1, "sched_get_priority_max"],
    160 : [1, "sched_get_priority_min"],
    161 : [2, "sched_rr_get_interval"],
    162 : [2, "nanosleep"],
    163 : [5, "mremap"],
    164 : [3, "setresuid"],
    165 : [3, "getresuid"],
    166 : [5, "vm86"],
    167 : [5, "query_module"],
    168 : [3, "poll"],
    169 : [3, "nfsservctl"],
    170 : [3, "setresgid"],
    171 : [3, "getresgid"],
    172 : [5, "prctl"],
    173 : [0, "rt_sigreturn"],
    174 : [4, "rt_sigaction"],
    175 : [4, "rt_sigprocmask"],
    176 : [2, "rt_sigpending"],
    177 : [4, "rt_sigtimedwait"],
    178 : [3, "rt_sigqueueinfo"],
    179 : [2, "rt_sigsuspend"],
    180 : [5, "pread64"],
    181 : [5, "pwrite64"],
    182 : [3, "chown"],
    183 : [2, "getcwd"],
    184 : [2, "capget"],
    185 : [2, "capset"],
    186 : [2, "sigaltstack"],
    187 : [4, "sendfile"],
    188 : [5, "getpmsg"],
    189 : [5, "putpmsg"],
    190 : [0, "vfork"],
    191 : [2, "ugetrlimit"],
    192 : [6, "mmap2"],
    193 : [3, "truncate64"],
    194 : [3, "ftruncate64"],
    195 : [2, "stat64"], 
    196 : [2, "lstat64"], 
    197 : [2, "fstat64"], 
    198 : [3, "lchown32"],
    199 : [0, "getuid32"],
    200 : [0, "getgid32"],
    201 : [0, "geteuid32"],
    202 : [0, "getegid32"],
    203 : [2, "setreuid32"],
    204 : [2, "setregid32"],
    205 : [2, "getgroups32"],
    206 : [2, "setgroups32"],
    207 : [3, "fchown32"],
    208 : [3, "setresuid32"],
    209 : [3, "getresuid32"],
    210 : [3, "setresgid32"],
    211 : [3, "getresgid32"],
    212 : [3, "chown32"],
    213 : [1, "setuid32"],
    214 : [1, "setgid32"],
    215 : [1, "setfsuid32"],
    216 : [1, "setfsgid32"],
    217 : [2, "pivot_root"],
    218 : [3, "mincore"],
    219 : [3, "madvise"],
    220 : [3, "getdents64"],
    221 : [3, "fcntl64"],
    223 : [5, "security"],
    224 : [0, "gettid"],
    225 : [4, "readahead"],
    226 : [5, "setxattr"],
    227 : [5, "lsetxattr"],
    228 : [5, "fsetxattr"],
    229 : [4, "getxattr"],
    230 : [4, "lgetxattr"],
    231 : [4, "fgetxattr"],
    232 : [3, "listxattr"],
    233 : [3, "llistxattr"],
    234 : [3, "flistxattr"],
    235 : [2, "removexattr"],
    236 : [2, "lremovexattr"],
    237 : [2, "fremovexattr"],
    238 : [2, "tkill"],
    239 : [4, "sendfile64"],
    240 : [6, "futex"],
    241 : [3, "sched_setaffinity"],
    242 : [3, "sched_getaffinity"],
    243 : [1, "set_thread_area"],
    244 : [1, "get_thread_area"],
    245 : [2, "io_setup"],
    246 : [1, "io_destroy"],
    247 : [5, "io_getevents"],
    248 : [3, "io_submit"],
    249 : [3, "io_cancel"],
    250 : [5, "fadvise64"],
    252 : [1, "exit_group"],
    253 : [4, "lookup_dcookie"],
    254 : [1, "epoll_create"],
    255 : [4, "epoll_ctl"],
    256 : [4, "epoll_wait"],
    257 : [5, "remap_file_pages"],
    258 : [1, "set_tid_address"],
    259 : [3, "timer_create"],
    260 : [4, "timer_settime"],
    261 : [2, "timer_gettime"],
    262 : [1, "timer_getoverrun"],
    263 : [1, "timer_delete"],
    264 : [2, "clock_settime"],
    265 : [2, "clock_gettime"],
    266 : [2, "clock_getres"],
    267 : [4, "clock_nanosleep"],
    268 : [3, "statfs64"],
    269 : [3, "fstatfs64"],
    270 : [3, "tgkill"],
    271 : [2, "utimes"],
    272 : [6, "fadvise64_64"],
    273 : [5, "vserver"],
    274 : [6, "mbind"],
    275 : [5, "get_mempolicy"],
    276 : [3, "set_mempolicy"],
    277 : [4, "mq_open"],
    278 : [1, "mq_unlink"],
    279 : [5, "mq_timedsend"],
    280 : [5, "mq_timedreceive"],
    281 : [2, "mq_notify"],
    282 : [3, "mq_getsetattr"],
    283 : [4, "kexec_load"],
    284 : [5, "waitid"],
    286 : [5, "add_key"],
    287 : [4, "request_key"],
    288 : [5, "keyctl"],
    289 : [3, "ioprio_set"],
    290 : [2, "ioprio_get"],
    291 : [0, "inotify_init"],
    292 : [3, "inotify_add_watch"],
    293 : [2, "inotify_rm_watch"],
    294 : [4, "migrate_pages"],
    295 : [4, "openat"],
    296 : [3, "mkdirat"],
    297 : [4, "mknodat"],
    298 : [5, "fchownat"],
    299 : [3, "futimesat"],
    300 : [4, "fstatat64"],
    301 : [3, "unlinkat"],
    302 : [4, "renameat"],
    303 : [5, "linkat"],
    304 : [3, "symlinkat"],
    305 : [4, "readlinkat"],
    306 : [3, "fchmodat"],
    307 : [3, "faccessat"],
    308 : [6, "pselect6"],
    309 : [5, "ppoll"],
    310 : [1, "unshare"],
    311 : [2, "set_robust_list"],
    312 : [3, "get_robust_list"],
    313 : [6, "splice"],
    314 : [6, "sync_file_range"],
    315 : [4, "tee"],
    316 : [4, "vmsplice"],
    317 : [6, "move_pages"],
    318 : [3, "getcpu"],
    319 : [6, "epoll_pwait"],
    320 : [4, "utimensat"],
    321 : [3, "signalfd"],
    322 : [2, "timerfd_create"],
    323 : [1, "eventfd"],
    324 : [6, "fallocate"],
    325 : [4, "timerfd_settime"],
    326 : [2, "timerfd_gettime"],
    327 : [4, "signalfd4"],
    328 : [2, "eventfd2"],
    329 : [1, "epoll_create1"],
    330 : [3, "dup3"],
    331 : [2, "pipe2"],
    332 : [1, "inotify_init1"],
    333 : [5, "preadv"],
    334 : [5, "pwritev"],
    335 : [4, "rt_tgsigqueueinfo"],
    336 : [5, "perf_event_open"],
    337 : [5, "recvmmsg"], 
    338 : [2, "fanotify_init"],
    339 : [6, "fanotify_mark"],
    340 : [4, "prlimit64"],
    341 : [5, "name_to_handle_at"],
    342 : [3, "open_by_handle_at"],
    343 : [2, "clock_adjtime"],
    344 : [1, "syncfs"],
    345 : [4, "sendmmsg"],
    346 : [2, "setns"],
    347 : [6, "process_vm_readv"],
    348 : [6, "process_vm_writev"],
    349 : [5, "kcmp"],
    350 : [3, "finit_module"],
    351 : [3, "sched_setattr"],
    352 : [4, "sched_getattr"],
    353 : [5, "renameat2"],
    354 : [3, "seccomp"],
    355 : [3, "getrandom"],
    356 : [2, "memfd_create"],
    357 : [3, "bpf"],
    358 : [5, "execveat"],
}

# x86_64 Definitions

x86_64_registers = {
    'rax' : ['rax'],
    'rbx' : ['rbx'],
    'rcx' : ['rcx'],
    'rdx' : ['rdx'],
    'rsp' : ['rsp'],
    'rbp' : ['rbp'],
    'rsi' : ['rsi'],
    'rdi' : ['rdi'],
    'rip' : ['rip'],
    'r8' : ['r8'],
    'r9' : ['r9'],
    'r10' : ['r10'],
    'r11' : ['r11'],
    'r12' : ['r12'],
    'r13' : ['r13'],
    'r14' : ['r14'],
    'r15' : ['r15'],
    'r8d' : ['r8'],
    'r9d' : ['r9'],
    'r10d' : ['r10'],
    'r11d' : ['r11'],
    'r12d' : ['r12'],
    'r13d' : ['r13'],
    'r14d' : ['r14'],
    'r15d' : ['r15'],
    'r8b' : ['r8'],
    'r9b' : ['r9'],
    'r10b' : ['r10'],
    'r11b' : ['r11'],
    'r12b' : ['r12'],
    'r13b' : ['r13'],
    'r14b' : ['r14'],
    'r15b' : ['r15'],
    'r8w' : ['r8'],
    'r9w' : ['r9'],
    'r10w' : ['r10'],
    'r11w' : ['r11'],
    'r12w' : ['r12'],
    'r13w' : ['r13'],
    'r14w' : ['r14'],
    'r15w' : ['r15'],
    'eax' : ['rax'],
    'ebx' : ['rbx'],
    'ecx' : ['rcx'],
    'edx' : ['rdx'],
    'esp' : ['rsp'],
    'ebp' : ['rbp'],
    'esi' : ['rsi'],
    'edi' : ['rdi'],
    'eip' : ['rip'],
    'eiz' : ['eiz'],
    'ax' : ['rax'],
    'bx' : ['rbx'],
    'cx' : ['rcx'],
    'dx' : ['rdx'],
    'si' : ['rsi'],
    'di' : ['rdi'],
    'bp' : ['bp'],
    'ah' : ['rax'],
    'al' : ['rax'],
    'bh' : ['rbx'],
    'bl' : ['rbx'],
    'ch' : ['rcx'],
    'cl' : ['rcx'],
    'dh' : ['rdx'],
    'dl' : ['rdx'],
    'spl' : ['rsp'],
    'bpl' : ['rbp'],
    'dil' : ['rdi'],
    'sil' : ['rsi'],
    'cs' : ['cs'],
    'ds' : ['ds'],
    'ss' : ['ss'],
    'es' : ['es'],
    'fs' : ['fs'],
    'gs' : ['gs'],
    'xmm0' : ['xmm0'],
    'xmm1' : ['xmm1'],
    'xmm2' : ['xmm2'],
    'xmm3' : ['xmm3'],
    'xmm4' : ['xmm4'],
    'xmm5' : ['xmm5'],
    'xmm6' : ['xmm6'],
    'xmm7' : ['xmm7'],
    'xmm8' : ['xmm8'],
    'xmm9' : ['xmm9'],
    'xmm10' : ['xmm10'],
    'xmm11' : ['xmm11'],
    'xmm12' : ['xmm12'],
    'xmm13' : ['xmm13'],
    'xmm14' : ['xmm14'],
    'xmm15' : ['xmm15'],
}

x86_64_syscall_table = { 
    0 : [3, "read"],
    1 : [3, "write"],
    2 : [3, "open"],
    3 : [1, "close"],
    4 : [2, "stat"],
    5 : [2, "fstat"],
    6 : [2, "lstat"],
    7 : [3, "poll"],
    8 : [3, "lseek"],
    9 : [6, "mmap"],
    10 : [3, "mprotect"],
    11 : [2, "munmap"],
    12 : [1, "brk"],
    13 : [4, "rt_sigaction"],
    14 : [4, "rt_sigprocmask"],
    15 : [0, "rt_sigreturn"],
    16 : [3, "ioctl"],
    17 : [4, "pread"],
    18 : [4, "pwrite"],
    19 : [3, "readv"],
    20 : [3, "writev"],
    21 : [2, "access"],
    22 : [1, "pipe"],
    23 : [5, "select"],
    24 : [0, "sched_yield"],
    25 : [5, "mremap"],
    26 : [3, "msync"],
    27 : [3, "mincore"],
    28 : [3, "madvise"],
    29 : [3, "shmget"],
    30 : [3, "shmat"],
    31 : [3, "shmctl"],
    32 : [1, "dup"],
    33 : [2, "dup2"],
    34 : [0, "pause"],
    35 : [2, "nanosleep"],
    36 : [2, "getitimer"],
    37 : [1, "alarm"],
    38 : [3, "setitimer"],
    39 : [0, "getpid"],
    40 : [4, "sendfile"],
    41 : [3, "socket"],
    42 : [3, "connect"],
    43 : [3, "accept"],
    44 : [6, "sendto"],
    45 : [6, "recvfrom"],
    46 : [3, "sendmsg"],
    47 : [3, "recvmsg"],
    48 : [2, "shutdown"],
    49 : [3, "bind"],
    50 : [2, "listen"],
    51 : [3, "getsockname"],
    52 : [3, "getpeername"],
    53 : [4, "socketpair"],
    54 : [5, "setsockopt"],
    55 : [5, "getsockopt"],
    56 : [5, "clone"],
    57 : [0, "fork"],
    58 : [0, "vfork"],
    59 : [3, "execve"],
    60 : [1, "_exit"],
    61 : [4, "wait4"],
    62 : [2, "kill"],
    63 : [1, "uname"],
    64 : [3, "semget"],
    65 : [3, "semop"],
    66 : [4, "semctl"],
    67 : [1, "shmdt"],
    68 : [2, "msgget"],
    69 : [4, "msgsnd"],
    70 : [5, "msgrcv"],
    71 : [3, "msgctl"],
    72 : [3, "fcntl"],
    73 : [2, "flock"],
    74 : [1, "fsync"],
    75 : [1, "fdatasync"],
    76 : [2, "truncate"],
    77 : [2, "ftruncate"],
    78 : [3, "getdents"],
    79 : [2, "getcwd"],
    80 : [1, "chdir"],
    81 : [1, "fchdir"],
    82 : [2, "rename"],
    83 : [2, "mkdir"],
    84 : [1, "rmdir"],
    85 : [2, "creat"],
    86 : [2, "link"],
    87 : [1, "unlink"],
    88 : [2, "symlink"],
    89 : [3, "readlink"],
    90 : [2, "chmod"],
    91 : [2, "fchmod"],
    92 : [3, "chown"],
    93 : [3, "fchown"],
    94 : [3, "lchown"],
    95 : [1, "umask"],
    96 : [2, "gettimeofday"],
    97 : [2, "getrlimit"],
    98 : [2, "getrusage"],
    99 : [1, "sysinfo"],
    100 : [1, "times"],
    101 : [4, "ptrace"],
    102 : [0, "getuid"],
    103 : [3, "syslog"],
    104 : [0, "getgid"],
    105 : [1, "setuid"],
    106 : [1, "setgid"],
    107 : [0, "geteuid"],
    108 : [0, "getegid"],
    109 : [2, "setpgid"],
    110 : [0, "getppid"],
    111 : [0, "getpgrp"],
    112 : [0, "setsid"],
    113 : [2, "setreuid"],
    114 : [2, "setregid"],
    115 : [2, "getgroups"],
    116 : [2, "setgroups"],
    117 : [3, "setresuid"],
    118 : [3, "getresuid"],
    119 : [3, "setresgid"],
    120 : [3, "getresgid"],
    121 : [1, "getpgid"],
    122 : [1, "setfsuid"],
    123 : [1, "setfsgid"],
    124 : [1, "getsid"],
    125 : [2, "capget"],
    126 : [2, "capset"],
    127 : [2, "rt_sigpending"],
    128 : [4, "rt_sigtimedwait"],
    129 : [3, "rt_sigqueueinfo"],
    130 : [2, "rt_sigsuspend"],
    131 : [2, "sigaltstack"],
    132 : [2, "utime"],
    133 : [3, "mknod"],
    134 : [1, "uselib"],
    135 : [1, "personality"],
    136 : [2, "ustat"],
    137 : [2, "statfs"],
    138 : [2, "fstatfs"],
    139 : [3, "sysfs"],
    140 : [2, "getpriority"],
    141 : [3, "setpriority"],
    142 : [2, "sched_setparam"],
    143 : [2, "sched_getparam"],
    144 : [3, "sched_setscheduler"],
    145 : [1, "sched_getscheduler"],
    146 : [1, "sched_get_priority_max"],
    147 : [1, "sched_get_priority_min"],
    148 : [2, "sched_rr_get_interval"],
    149 : [2, "mlock"],
    150 : [2, "munlock"],
    151 : [1, "mlockall"],
    152 : [0, "munlockall"],
    153 : [0, "vhangup"],
    154 : [3, "modify_ldt"],
    155 : [2, "pivot_root"],
    156 : [1, "_sysctl"],
    157 : [5, "prctl"],
    158 : [2, "arch_prctl"],
    159 : [1, "adjtimex"],
    160 : [2, "setrlimit"],
    161 : [1, "chroot"],
    162 : [0, "sync"],
    163 : [1, "acct"],
    164 : [2, "settimeofday"],
    165 : [5, "mount"],
    166 : [2, "umount2"],
    167 : [2, "swapon"],
    168 : [1, "swapoff"],
    169 : [4, "reboot"],
    170 : [2, "sethostname"],
    171 : [2, "setdomainname"],
    172 : [1, "iopl"],
    173 : [3, "ioperm"],
    174 : [2, "create_module"],
    175 : [3, "init_module"],
    176 : [2, "delete_module"],
    177 : [1, "get_kernel_syms"],
    178 : [5, "query_module"],
    179 : [4, "quotactl"],
    180 : [3, "nfsservctl"],
    181 : [5, "getpmsg"],
    182 : [5, "putpmsg"],
    183 : [5, "afs_syscall"],
    184 : [3, "tuxcall"],
    185 : [3, "security"],
    186 : [0, "gettid"],
    187 : [3, "readahead"],
    188 : [5, "setxattr"],
    189 : [5, "lsetxattr"],
    190 : [5, "fsetxattr"],
    191 : [4, "getxattr"],
    192 : [4, "lgetxattr"],
    193 : [4, "fgetxattr"],
    194 : [3, "listxattr"],
    195 : [3, "llistxattr"],
    196 : [3, "flistxattr"],
    197 : [2, "removexattr"],
    198 : [2, "lremovexattr"],
    199 : [2, "fremovexattr"],
    200 : [2, "tkill"],
    201 : [1, "time"],
    202 : [6, "futex"],
    203 : [3, "sched_setaffinity"],
    204 : [3, "sched_getaffinity"],
    205 : [1, "set_thread_area"],
    206 : [2, "io_setup"],
    207 : [1, "io_destroy"],
    208 : [5, "io_getevents"],
    209 : [3, "io_submit"],
    210 : [3, "io_cancel"],
    211 : [1, "get_thread_area"],
    212 : [3, "lookup_dcookie"],
    213 : [1, "epoll_create"],
    214 : [4, "epoll_ctl_old"],
    215 : [4, "epoll_wait_old"],
    216 : [5, "remap_file_pages"],
    217 : [3, "getdents64"],
    218 : [1, "set_tid_address"],
    219 : [0, "restart_syscall"],
    220 : [4, "semtimedop"],
    221 : [4, "fadvise64"],
    222 : [3, "timer_create"],
    223 : [4, "timer_settime"],
    224 : [2, "timer_gettime"],
    225 : [1, "timer_getoverrun"],
    226 : [1, "timer_delete"],
    227 : [2, "clock_settime"],
    228 : [2, "clock_gettime"],
    229 : [2, "clock_getres"],
    230 : [4, "clock_nanosleep"],
    231 : [1, "exit_group"],
    232 : [4, "epoll_wait"],
    233 : [4, "epoll_ctl"],
    234 : [3, "tgkill"],
    235 : [2, "utimes"],
    236 : [5, "vserver"],
    237 : [6, "mbind"],
    238 : [3, "set_mempolicy"],
    239 : [5, "get_mempolicy"],
    240 : [4, "mq_open"],
    241 : [1, "mq_unlink"],
    242 : [5, "mq_timedsend"],
    243 : [5, "mq_timedreceive"],
    244 : [2, "mq_notify"],
    245 : [3, "mq_getsetattr"],
    246 : [4, "kexec_load"],
    247 : [5, "waitid"],
    248 : [5, "add_key"],
    249 : [4, "request_key"],
    250 : [5, "keyctl"],
    251 : [3, "ioprio_set"],
    252 : [2, "ioprio_get"],
    253 : [0, "inotify_init"],
    254 : [3, "inotify_add_watch"],
    255 : [2, "inotify_rm_watch"],
    256 : [4, "migrate_pages"],
    257 : [4, "openat"],
    258 : [3, "mkdirat"],
    259 : [4, "mknodat"],
    260 : [5, "fchownat"],
    261 : [3, "futimesat"],
    262 : [4, "newfstatat"],
    263 : [3, "unlinkat"],
    264 : [4, "renameat"],
    265 : [5, "linkat"],
    266 : [3, "symlinkat"],
    267 : [4, "readlinkat"],
    268 : [3, "fchmodat"],
    269 : [3, "faccessat"],
    270 : [6, "pselect6"],
    271 : [5, "ppoll"],
    272 : [1, "unshare"],
    273 : [2, "set_robust_list"],
    274 : [3, "get_robust_list"],
    275 : [6, "splice"],
    276 : [4, "tee"],
    277 : [4, "sync_file_range"],
    278 : [4, "vmsplice"],
    279 : [6, "move_pages"],
    280 : [4, "utimensat"],
    281 : [6, "epoll_pwait"],
    282 : [3, "signalfd"],
    283 : [2, "timerfd_create"],
    284 : [1, "eventfd"],
    285 : [4, "fallocate"],
    286 : [4, "timerfd_settime"],
    287 : [2, "timerfd_gettime"],
    288 : [4, "accept4"],
    289 : [4, "signalfd4"],
    290 : [2, "eventfd2"],
    291 : [1, "epoll_create1"],
    292 : [3, "dup3"],
    293 : [2, "pipe2"],
    294 : [1, "inotify_init1"],
    295 : [4, "preadv"],
    296 : [4, "pwritev"],
    297 : [4, "rt_tgsigqueueinfo"],
    298 : [5, "perf_event_open"],
    299 : [5, "recvmmsg"],
    300 : [2, "fanotify_init"],
    301 : [5, "fanotify_mark"],
    302 : [4, "prlimit64"],
    303 : [5, "name_to_handle_at"],
    304 : [3, "open_by_handle_at"],
    305 : [2, "clock_adjtime"],
    306 : [1, "syncfs"],
    307 : [4, "sendmmsg"],
    308 : [2, "setns"],
    309 : [3, "getcpu"],
    310 : [6, "process_vm_readv"],
    311 : [6, "process_vm_writev"],
    312 : [5, "kcmp"],
    313 : [3, "finit_module"],
    314 : [3, "sched_setattr"],
    315 : [4, "sched_getattr"],
    316 : [5, "renameat2"],
    317 : [3, "seccomp"],
    318 : [3, "getrandom"],
    319 : [2, "memfd_create"],
    320 : [5, "kexec_file_load"],
    321 : [3, "bpf"],
    322 : [5, "execveat"],
}
